## Changelog

### `0.1.2` (unreleased)

- [#17] adds foreground and background layers with customized per-cell styling

[#17]: https://github.com/deathbeds/jupyterlab-deck/issues/15

### `0.1.1`

#### Enhancements

- improve keyboard navigation with (<kbd>shift</kbd>)<kbd>space</kbd>
- the active cell is scrolled into view when exiting presentation mode

#### Bug Fixes

- fix some packaging metadata and documentation issues
- fix handling of `null` cells

### `0.1.0`

_initial release_
